\name{aov.tab.varcomp.2.file}
\alias{aov.tab.varcomp.2.file}
\title{Calculate ANOVA table and variance components and write them into
  a file.}
\description{
  Function aov.tab.varcomp.2.file takes a YASMA bfaov object and the
  fspma's info structure and writes an ANOVA table and the variance
  components into a file.
}
\usage{aov.tab.varcomp.2.file(av, info, model.info, file=NULL)}
\arguments{
  \item{av}{YASMA's bfaov object}
  \item{info}{fspma's info structure}
  \item{model.info}{fspma's model.info structure}
  \item{file}{optional file name, if NULL the file name is taken from
    info\$aovfname}
}
\value{
  The function aov.tab.varcomp.2.file takes the bfaov object and some
  control information from info and model.info to generate the ANOVA table and
  calculate and write the variance components to a file. The file name in
  info\$aovfname is obtained from the 'ANOVA.Outfile:' entry in the
  definition file. The function has no return object.
}
\examples{
\dontrun{
## read definition file
info <- read.defs('deffile.def')
## extract model.info from the info structure
model.info <- info.2.yasmaeqns(info)
## read data
RG <- tabdel2rg(info)
## and normalize it
RG <- do.normalize(RG, info)
## convert to array structure
aov.a <- rg2log.array(RG, log.ratio=T)
## and call do.anova
av <- do.anova(model.info, aov.a)
## write the ANOVA and reml variance table according to info
aov.tab.varcomp.2.file(av, info, mode.info) 
}
}
\seealso{
  \code{\link{tabdel2rg}}, \code{\link{do.normalize}}, \code{\link{do.anova}},
  \code{\link{aov.tab.varcomp.2.file}} and \code{\link{contrast.rank.2.file}}
}
\keyword{print}
\keyword{IO}
