\name{contrast.rank.2.file}
\alias{contrast.rank.2.file}
\title{Calculate contrast based within ANOVA rankings and write
  resulting gene lists to tab delimited files.}
\description{
  Function contrast.rank.2.file takes a YASMA bfaov object, YASMA's RG
  structure, fspma's info and model.info structures, calculates the
  rank lists and writes all information (including the
  within group sample means) into a results file.
}
\usage{contrast.rank.2.file(av, RG, model.info, info, p.type, p.thrs,
n.comps, log.fname = fspma.logfile)}
\arguments{
  \item{av}{YASMA's bfaov object.}
  \item{RG}{YASMA's RG structure.}
  \item{model.info}{fspma's model.info structure.}
  \item{info}{fspma's info structure.}
  \item{p.type}{P-value adjustment (defult from info)}
  \item{p.thrs}{Threshold of p-value or top rank counter}
  \item{n.comps}{Overall number of comparisons (calculated by
    fspma.wrapper)}
  \item{log.fname}{Name of log file used to dump progress report}
}
\value{contrast.rank.2.file writes rank tables to tab delimited files
  and returns a list of all rank tables to the calling function. Note
  that the returned object is not meant to be manipulated at user
  level.}

\section{File structure}{  
  The function contrast.rank.2.file takes the bfaov object and some
  control information to generate contrast based rank tables within the
  ANOVA. Each comparison is written in its own tab delimited file.
  The files contains the index of the gene in the gene list, the gene
  name, an adjusted p-value, a boolean indicator of upregulation and sample
  means in each level of th erank effect. Upregulation is decided based
  on the sign of the comparison. If it specifies a base level, upregulation
  indicates a significantly larger (differential) expression in the
  second level of the comparison. In case of a contrast, upregulation indicates
  that the average differential expression at the levels that have
  positive weight is higher than the average differential expression at
  the levels that have negative weight (see also the example
  below).\cr \cr
  The function is controlled by info\$contrast, info\$p.type and
  info\$p.thrs. The file name base is specified as info\$ctrfname, it
  represents the file name in the 'Contrast.Outfile:' line in the
  definition file. The component info\$contrast is obtained from the
  'Base.Contrast:' entry in the definition file. The name part of the
  contrast entry (first string after tabulator) is concattenated to the
  file base name to make a unique augmented file base.}

\section{Base Levels - Multiple Pairwise Comparisons}{
  There are two different ways to specify a contrast: First one can
  provide an index of a base level of the rank effect. This base level is
  compared to all other levels of the effect (e.g. for comparing adult
  against all other generations in a time course). In this case there
  is one ranking obtained for every level in the rank effect that
  differs from the base level. Each ranking is stored in a separate
  file that starts with "test." followed by the level name and the augmented
  file base to give a unique file name.
  Ranking is based on the corresponding p-values that are adjusted
  based on the overall number of comarisons suggested by the definition
  file, which is vital to get less false positives.}

\section{Contrasts}{
  The other option requires as many entries as there are levels to
  specify a contrast directly. If the contrasts do not sum to zero,
  positive and negative contrasts are normalized separately.
  In a mammary gland study with entries 'day 0 lactation', 'day 5 lactation',
  'day 10 lactation', '12 hrs involution', '24 hrs involution', '72 hrs
  involution' and '96 hrs involution' we can thus use the contrast
  -1<TAB>-1<TAB>-1<TAB>-1<TAB>1<TAB>1<TAB>1 to specify a contrast
  that ranks w.r.t. a type 2 apoptosis event. (The values are
  normalized to -1/4 and 1/3 respectively and upregulation "TRUE" would denote
  those genes that are upregulated at late involution time points). The
  file name is generated by the contrast name that is concatenated with the file base
  specified as 'Contrast.Outfile:'.}

\section{Controling Significance}{
  The component info\$p.type is obtained from the 'Comp.Type:' entry that
  can specify various adjustments (see p.adjust in R or
  \code{\link{deffile.def}} for help). The number of comparisons to be
  done within one analysis run (i.e. specified within a definition
  file) is used as counts to adjust the p-values.
  
  The component info\$p.thrs is obtained from the 'Comp.Thrs:' entry that
  either specifies a p-value threshold or if it is an integer number
  a count of how many of the most significant genes should be written
  into the file.
}

\examples{
\dontrun{
## read definition file
info <- read.defs('deffile.def')
## extract model.info from the info structure
model.info <- info.2.yasmaeqns(info)
## read data
RG <- tabdel2rg(info)
## normalize it
RG <- do.normalize(RG, info)
## convert to array structure
aov.a <- rg2log.array(RG, log.ratio=T)
## call do.anova
av <- do.anova(model.info, aov.a)
## and calculate and write within ANOVA rank tables.
contrast.rank.2.file(av, RG, model.info, info, n.comps=[plug in here!])
}
}
\seealso{
  \code{\link{tabdel2rg}}, \code{\link{do.normalize}}, \code{\link{do.anova}},
  \code{\link{deffile.def}} and \code{\link{aov.tab.varcomp.2.file}}
}
\keyword{IO}
\keyword{print}
