\name{deffile.def}
\docType{data}
\alias{deffile.def}
\title{Example definition file for fspma.wrapper}
\description{
  Definition file that controls the execution of the fspma scripts.
}
\usage{deffile.def}
\format{deffile.def is a file name that refers to a tab delimited
  definition file which controls all aspects of evaluating a miroarray
  experiment. It is used as parameter to \code{fspma.wrapper}(deffile),
  see \code{\link{fspma.wrapper}}.
}
\details{
  The tags at the beginning of each line identify the information fspma
  uses to control the analysis of a microarray experiment.
  It is of vital importance that they are typed exactly, since
  they are searched for. Lines starting with \# are regarded as comments.
  All different specifiers within a line (e.g. the numbers
  of instances for each effect in the 'Effects:' row) must be separated
  by Tabulators. Avoid at every cost extra (trailing!) white spaces
  (blanks, tabulators, etc.), because these will lead to completely
  undesired behaviour! The following provides an example definition
  file. For a detailed discussions of various options refer to the
  man pages of individual functions. Also refer to the examples provided
  with the library and the online example
  at \url{http://www.ccbi.cam.ac.uk/software/psyk/software.html#fspma} that can
  be used in connection with a dataset that is available online.
}
\examples{
\dontrun{
# Definition file for ANOVA analysis of an experiment.
# This file is the interface of any experiment that can be analysed
# by YASMA. It is read by an r-script that loads data and prepares all
# what is needed afterwards during the analysis.
# 
# (C) P. Sykacek 2004.
#
# Version information: This will be counted up if changes are made to
# the structure of the definition file, to be able to parse old files as
# well. Note that the description of old files is no longer available,
# as soon as this gets updated. (i.e. version 1 is obsolete by now)
Ver:	2
#
ExpName:	Mouse Testis
#
# All effects that appear in the experiment. The last is the
# minimum number of replicates per slide and must be specified.
Effects:	7	4	2
#
# Experiment is Unbalanced: (Otherwise an error is raised if the
# experiment is unbalanced!) Unbalanced experiments can be loade and
# normalized. An ANOVA analysis however is not possible.
Is.Unbalanced:	F
#
# Effect Names: (compatible with R variable names, no blanks and underscore)
Eff.Nams:	time	sample	rep
#
# which are random effects
RandEffs:	F	T	T
#
# Which effect should be ranked over?
Rank.Eff:	1
#
# Names of each ranking dimension that need to be compatible with R variable
# names. Hence no blanks and underscores.
Rank.Names:	adult	day.1	day.5	day.10	day.15	day.23	day.35
#
# The following line either specifies a contrast or a base level to be used for
# ranking within the ANOVA model.
# There are 3 possibilities: specify a contrast; specify a base level
# of the rank effect that all other levels should be compared against;
# specify ANOVA based ranking, where the p-value of each time course (or the
# respective type) is evaluated with an ANOVA model.
# Novel: since we allow for multiple comparisons in one file we add
# a name for each contrast that enters the file name.
# Example for a contrast comparing day 15 versus adult
# Base.Contrast:	ctadd15	-1	0	0	0	1	0	0
# Example for general ranking against adult (takes most significant p-value 
# for each gene)
# Base.Contrast:	blad	1
# If there is only one level in the rank effect the previous line ranks
# based on significant differential expression between the two channels.
# Example for ANOVA based ranking:
# Base.Contrast:	ANOVA
# Example for VARIETY based ranking. Only for two channel arrays
# where this compares the average log ratios against each other:
# Base.Contrast:	VARIETY
# Several Base.Contrast: entries are possible. They will all be analysed
# together with p-values adjusted accordingly.
# The following example specifies two base levels and does hence 12
# pairwise comparisons for every gene. This is one replicated, which
# will lead to a conservative p-value adjustment. This can be avoided by
# using one base level and specify the remaining 5 pairwise comparisons
# by conventional contratsts.
Base.Contrast:	blad	1
Base.Contrast:	bld01	2
# Output file to write the gene list from the comparison, 
# use NA if not required
Contrast.Outfile:	testis_gen_comp.tsv
# Type of p-value adjustment: holm, hochberg, hommel, bonferroni, fdr,
# none (from R{stats} p.adjust)
Comp.Type:	bonferroni
# p-value threshold or integer number interpreted as top-ranked count.
Comp.Thrs:	0.05
# ANOVA table and variance component output file
ANOVA.Outfile:	mouse_testis_aov.txt
#
# Normalization control; NA if none otherwise loess,
# location or scale combinations like loess scale or
# location scale are allowed as well. For loess scale the order matters!
# This is an interface to YASMA's functionality.
# loess with optional span and degree (0.25< span <=1 and degree 1 or 2)
# default is 0.9 for the span and 1 for the degree.
# Normalization:	loess	[<span>	[<degree>]]
# IMPORTANT: Without spike genes, loess is invalid for single channel arrays!
# Normalization:	localtion
# Normalization:	location	scale
# Normalization:	loess	scale
# Version 2 allows spike based normalization which is initialised using
# the modifier spike. e.g.
# Normalization:	spike	location
# In addition to location and scale more elaborate versions based on
# grid position and amplitude are possible. The latter fits a loess fit
# to the spikes residuals and subtracts that from all other gene values.
# (which depending on the data, are either log ratios or log expressions).
# possible values are spatial and amplitude e.g.
# Normalization:	spike	spatial	amplitude
# Spike normalization can be modified by grid and scale and by two
# numerical values which are taken as loess span and degree. Modifier grid
# uses grid numbers as factors in the loess model equation and allows to
# remove pin effects. Spike based normalization requires a list of
# spikes and expected expressions to be provided after spike.list: (see below)
# The following is a possible setting for spike based normalization.
# It uses a loess fit with spatial position (spatial effects) and
# amplitude (spot intensity) as continuous regressors and the grid
# index (pin effects) as factorial regressor. The optional span and
# degree of the loess fit are here set to 0.95 and 1 respectively.
# After calculating the overall scale, each slide is 
# transformed to that scale.
Normalization:	spike	0.95	1	spatial	amplitude	grid	scale
#
# Control conversion; RG -> array (T -> take log, F -> use data as is)
DoRG2logarray:	T
#
# Value for flagged entries; If available checked against Flag. column
# The flag value can be numeric or string and there can be more than one
# value in this line, separated by tabulators.
# For bluefuse manual exclusion:
# Flag.NOK:	yes
# For genepix : (both automatic and manually excluded flags)
# Flag.NOK:	-50	-100
Flag.NOK:	NA
#
# Select method to impute NA values. This is needed in connection with
# Flags to deal with missing values.
# Remove genes with missing spots from analysis:
# Impute.Mthd:	del
# Impute with knn (Trojanskaya's Bioinformatics publication), k is an
# integer number (the number of neighbours that are considered):
# Impute.Mthd:	knn	k
# Note that in case we find missing spots and NA was selected,
# the script issues a waning and changes to "del". Otherwise the
# subsequent analysis will crash.
# No imputation:
Impute.Mthd:	NA
#
# Load.Only allows to control the program flow in the script. If T
# The script aborts after loading the data before anything else has
# been done with the data. Together with an alternative entry,
# this gives the user some flexibility to process data in a more
# flexible way by combining the automatic analysis with other R-code.
Load.Only:	F
#
# The following entry allows to write the normalized log ratios to an output file.
# NA is for none. The string is actually only the base file name with two 
# endings. In this case 'nia_rawlogrt.tsv' contains the data that was
# processed acording to the normalization and log options. Data is
# stored row wise (i.e. each full set of genes is one row) with the gene
# symbols used as colum names. The second file has as many rows as the
# previous, such that each row identifies the level settings of the
# corresponding data row. In this case it would be named 'nia_raweffdesc.tsv'.
DataOutFnam:	nia_raw
#
# The following definitions allow to identify the various columns that
# are extracted from the tab delimited microarray files.
# column of gene name and its name in the header
gene.colnam:	NAME
#
# column of Cy5 spot and its name in the header
R.colnam:	AMPCH1
#
# column of Cy5 background and its name in the header: NA if unavailable.
Rb.colnam:	NA
#
# column of Cy3 spot and its name in the header: may be missing (NA)
G.colnam:	AMPCH2
#
# column of Cy3 background and its name in the header
Gb.colnam:	NA
#
# column of flag id and its name in the header
Flag.colnam:	NA
#
# X-pos column name (NA if none)
X.colnam:	PELCOL
#
# Y-pos column name (NA if none)
Y.colnam:	PELROW
#
# Grid.no. column name (NA if none)
Grid.colnam:	BLOCK
#
# gene info columns (NA if none)
# These columns are expected to contain standardised information
# about genes. The first column name provided here should contain
# short gene symbols because this information will be used in all
# plot legends. The other columns are only written into tab delimited
# output files and can thus contain arbitrary long strings.
gene.infocols:	GENESYMBOL	GENEDESCRIPTION
#
# Do a fast file load? If one sets load.fast: to TRUE, fspma assumes that
# the positions of genes found in the first file is identical with the
# gene positions in all subsequent files. This speeds up data loading
# considerably. If there is any doubt about whether the gene positions
# are identical, one should always set this flag "FALSE".
fast.load:	F
#
# Next: allocate files to experiments. The number is obtained automatically from
# the effects description. First column: file name , then no effects minus 1 
# columns to allocate the data and as final column a Boolean flag (T or F) 
# indicating whether the corresponding file contains a dye swap.
# Unless one states that Is.Unbalanced:	T (is true), all levels of
# the effects have to be allocated. Missing specifications lead to an
# error message and processing terminates.
file.alloc:
# adult generation			time	sample	dye swap?
R35_NIA1_AWX_ad_612_Fl_output.xls	1	1	F
R35_NIA1_AWX_ad_613_Fl_output.xls	1	2	F
R35_NIA1_AWX_ad_629b_Fl_output.xls	1	3	F
R35_NIA1_AWX_ad_630_Fl_output.xls	1	4	F
# day one
R25_NIA1_AWX_d01_s16_Fl_output.xls	2	1	F
R25_NIA1_AWX_d01_s17_Fl_output.xls	2	2	F
R25_NIA1_AWX_d01_s18_Fl_output.xls	2	3	F
R25_NIA1_AWX_d01_s21_Fl_output.xls	2	4	F
# day 5
R25_NIA1_AWX_d05_s13_Fl_output.xls	3	1	F
R35_NIA1_AWX_d05_545_Fl_output.xls	3	2	F
R35_NIA1_AWX_d05_546_Fl_output.xls	3	3	F
R35_NIA1_AWX_d05_547_Fl_output.xls	3	4	F
# day 10
R25_NIA1_AWX_d10_s28_Fl_output.xls	4	1	F
R35_NIA1_AWX_d10_596_Fl_output.xls	4	2	F
R35_NIA1_AWX_d10_597_Fl_output.xls	4	3	F
R35_NIA1_AWX_d10_600_Fl_output.xls	4	4	F
# day 15
R35_NIA1_AWX_d15_594_Fl_output.xls	5	1	F
R35_NIA1_AWX_d15_605_Fl_output.xls	5	2	F
R35_NIA1_AWX_d15_671_Fl_output.xls	5	3	F
R35_NIA1_AWX_d15_674_Fl_output.xls	5	4	F
# day 23
R35_NIA1_AWX_d23 653_Fl_output.xls	6	1	F
R35_NIA1_AWX_d23 654_Fl_output.xls	6	2	F
R35_NIA1_AWX_d23 655b_Fl_output.xls	6	3	F
R35_NIA1_AWX_d23 670_Fl_output.xls	6	4	F
# day 35
R35_NIA1_AWX_d35_631_Fl_output.xls	7	1	F
R35_NIA1_AWX_d35_632_Fl_output.xls	7	2	F
R35_NIA1_AWX_d35_633_Fl_output.xls	7	3	F
R35_NIA1_AWX_d35_651_Fl_output.xls	7	4	F
# 
# Provide the spike list with
# name<TAB>R_concentration<TAB>G_concentration. Note that
# R and G refer to the above channel names and are the
# known spike concentration in that channel (only the
# correct ratio is important). Hence 1<TAB>1 would also
# be apropriate for non differentially expressed housekeeping genes.
spike.list:
#                       R_con.	G_con.
Ctl141002_01_A01	1	1
Ctl141002_01_A02	1	1
Ctl141002_01_A03	1	1
Ctl141002_01_A04	1	1
Ctl141002_01_A05	1	1
Ctl141002_01_A06	1	1
Ctl141002_01_A07	1	1
#... and more if available
# Finally a list of all unique gene names (as found in gene.col in the data).
# That should go into the experiment. This is necessary to allow for
# experiment designs where people use different numbers of replicates
# on slide.
genes.list:
H3078A06
H3078C06
H3078E06
H3078G06
H3078A12
#... and many more gene id.'s (all are required!)
}
}
\seealso{\code{\link{do.normalize}} and \code{\link{spike.normalize}} for
  further discussion of available normalization options,
  \code{\link{contrast.rank.2.file}} for an
  explanation of all possibilities with the contrast entries,
  \code{\link{specify.experiments}} for how to specify different
  experiments and \code{\link{fspma.wrapper}} on how to get the
  analysis started. 
}
\keyword{documentation}
\keyword{file}

