\name{do.normalize}
\alias{do.normalize}
\alias{fspma.logRG.loess.norm}
\alias{fspma.logRG.shift.norm}
\alias{fspma.logRG.scale.norm}
\title{Controls the normalization procedure in fspma.wrapper.}
\description{Some simple slide normalization procedures can be
  selected via the definition file. These include within slide
  location (i.e. mean) removal, within slide loess normalization, scale
  removal (i.e. convert log ratios within slide to unit std. deviation) or
  none, if normalization is done as an extra preprocessing step.
}
\usage{do.normalize(RG, info, log.fname=fspma.logfile)
fspma.logRG.loess.norm(RG, deg=1, span=0.6, show=T, show.new=F, flat=F, tolog=F,...)
fspma.logRG.shift.norm(RG,method=c("mean","median"), tolog=F)
fspma.logRG.scale.norm(RG,method=c("sd","mad"), tolog=F)
}
\arguments{
  \item{RG}{data structure as described in YASMA (and SMA)}
  \item{info}{control structure as obtained by \code{\link{read.defs}}}
  \item{log.fname}{Log file name to dump status messages, defaults to fspma.logfile}
  \item{deg}{polynomial degree of loess fit}
  \item{span}{span of loess fit}
  \item{show}{boolean flag to control graphical illustration}
  \item{show.new}{boolean flag to control graphical illustration (after
    normalisation)}
  \item{flat}{boolean flag to control graphical illustration (if TRUE,
    plot base line instead of loess curve in figure)}
  \item{method}{specify how the location (for shift) or scale of the
    data are obtained}
  \item{tolog}{boolean flag that decides whether data is moved to log
    scale or whether it is already on log scale.}
  \item{...}{Parameters handed through to plot function.}
}
\value{All functions return a normalised RG object.}
\details{Normalization is controlled by info\$norm.type, a vector that
  contains the control statements in the "Normalization:" line in the
  definition file. Valid entries are NA, loess, location, scale and
  combinations like location<TAB>scale and loess<TAB>scale. For loess
  one can optionally specify a span (between 0.25 and 1) and a degree
  (1 or 2). The function returns RG, the experiments RG structure with
  all data normalized within slides.
  \bold{Without spike genes, loess is invalid for all single
    channel specifications!} Consequently this setting is not accepted.
  FSPMA provides slightly modified versions of YASMAs original
  normalisation functions (\code{fspma.logRG.loess.norm},
  \code{fspma.logRG.shift.norm} and \code{fspma.logRG.scale.norm}). The
  essential difference is that FSMPA must cope with data that
  is on log scale. This changes how data is moved to the log ratio -
  amplitide representation.
}
\examples{
\dontrun{
## read definition file
info <- read.defs('deffile.def')
## read data
RG <- tabdel2rg(info)
## and normalize it
RG <- do.normalize(RG, info)
}
}
\seealso{
  \code{\link{fspma.wrapper}} and \code{\link{spike.normalize}} 
}
\keyword{misc}