\name{do.rank.variety}
\alias{do.rank.variety}
\title{Variety based ranking of time course data (or other multi-level effects)}
\description{
  "Variety" based ranking for significant differences of average channei
  expression over the entire experiment.
}
\usage{do.rank.variety(av, RG, model.info, info, n.comps)}
\arguments{
  \item{av}{YASMA's bfaov object.}
  \item{RG}{YASMA's RG structure.}
  \item{model.info}{fspma's model.info structure.}
  \item{info}{fspma's info structure.}
  \item{n.comps}{Overall number of comparisons (calculated by
    fspma.wrapper over all comparisons specified in the definition
    file.)}
}
\value{
  do.rank.variety provides a ranking that assesses the average channel
  log ratios for significance. A rank table is written as tab delimited
  file and returned as object to the calling function. Note that this
  object is not intended to be modified at user level. 
}
\details{Variety based ranking is available with the standard YASMA
  package. The function do.rank.variety wraps around
  a version in YASMA that is based on within ANOVA ranking, using
  t-distributions. This approach is only useful for dual channel
  reference designs, where one tryes to assess significance between the
  two groups that make up the RNA mix of each channel.
  Ranking is based on YASMA's bfaov object that is used to extract all
  relevant information. The null hypothesis is zero log ratios. The rank
  table contains gene indices, names, adjusted p-values, an
  up-regulation flag and the average log ratio.
  It is written tab delimited to a file that concatenates
  'test.variety.' with the name specified as info\$ctrfname (the
  'Contrast.Outfile:' entry in the definition file). Although it will
  produce outputs for single channel arrays, this procedure makes
  conceptually no sense in that case!
}
\examples{
\dontrun{
## read definition file
info <- read.defs('deffile.def')
## extract model.info from the info structure
model.info <- info.2.yasmaeqns(info)
## read data
RG <- tabdel2rg(info)
## and normalize it
RG <- do.normalize(RG, info)
## convert to array structure
aov.a <- rg2log.array(RG, log.ratio=T)
## and call do.anova
av <- do.anova(model.info, aov.a)
## calculate and write ANOVA rank tables (one ANOVA per gene).
do.rank.variety(av, RG, model.info, info, n.comps=[plug in here])
}
}
\seealso{
  \code{\link{tabdel2rg}}, \code{\link{do.normalize}}, \code{\link{do.anova}},
  \code{\link{aov.tab.varcomp.2.file}} \code{link{fspma.aovrnk}} and
  \code{\link{contrast.rank.2.file}}
}
\keyword{models}
\keyword{multivariate}
\keyword{print}
