\name{fspma.avchannel}
\alias{fspma.avchannel}
\alias{fspma.av.RG2file}
\alias{fspma.av.scattp}
\title{Conversion of FSPMA objects to average channel expressions,
  storage and visualisation}
\description{
  These functions extract average channel expressions or information
  derived from FSPMA objects (e.g. evaluating contrasts). They allow to
  store and plot the resulting representation.
}
\usage{
fspma.avchannel(fspma.obj, contrast=NULL, statenames=NULL, log2exp=F)
fspma.av.RG2file(fspma.av.RG, filename='average.channels.tsv')
fspma.av.scattp(fspma.av.RG, statename, filename='NA',
pl.title='Scatter Plot Average Expression',
x.leg='Average log channel value in G',
y.leg='Average log channel value in R',
nsamples=50, lg.diff=2, ndiff.smpls=5, plt.lwd=1,
n.sz=0.5, ud.sz=2, col.frst=T, p.dim=7.0, leg.pos='bottomright',
leg.bty='n')
}
\arguments{
  \item{fspma.obj}{is a FSPMA object as generated by fspma.wrapper}
  \item{contrast}{Optional contrast definition used to obtain channel averages
    over subsets of rank levels. These contrasts are of identical length
    and struture as those specified in the definition file.}
  \item{statenames}{Optional state names. Default are the rank names
    from the definition file and "diff" for average expression according
    to a contrast.}
  \item{log2exp}{Boolean control whether we exponentiate the
    averages. Defaults to FALSE.}
  \item{fspma.av.RG}{An average channel object that is obtained by
    calling fspma.avchannel.}
  \item{filename}{In fspma.av.RG2file: a file name that is used to store the average
    expressions in a tab delimited format with "average.channels.tsv" as
    default value. In fspma.av.scattp: a file name to store the figure as
    encapsulated postscript or 'new' if a new graphics window should be
    used. In the default case of 'NA', the current "device" is used for
    plotting.} 
  \item{statename}{Name of the level one intends to visualise in the
    scatter plot. In the default case this is either a rank name or
    "diff".}
  \item{pl.title}{Plot Title.}
  \item{x.leg}{X axis legend.}
  \item{y.leg}{Y axis legend.}
  \item{nsamples}{Number of subsampled "non suspicious" genes to be plotted.}
  \item{lg.diff}{Average log fold indication lines (NA for none).}
  \item{ndiff.smpls}{Number of suspicious genes to be plotted (those
    with largest up and down regulation).}
  \item{plt.lwd}{Line width in plot.}
  \item{n.sz}{Point size for non suspicious genes.}
  \item{ud.sz}{Point size for suspicious genes.}
  \item{col.frst}{Boolean flag to control whether colour or symbols
    should alter first.}
  \item{p.dim}{Figure dimension in postscript device.}
  \item{leg.pos}{Position of legend (see plot legend function).}
  \item{leg.bty}{Type of legend bounding box (see plot legend function).}
}
\value{
  \code{fspma.avchannel} converts a FSPMA object to a fspma.av.RG object
  which stores average channel expression values. The other functions
  have no return value. They write information to files or plots.
}
\examples{
\dontrun{
fspma.obj <- fspma.wrapper('twochannel.def')
fspma.av <- fspma.avchannel(fspma.obj)
allnams <- fspma.obj$info$rank.names
fspma.av.scattp(fspma.av.RG, allnams[1])
}
}
\seealso{
  \code{\link{fspma.wrapper}} and \code{\link{fspma.rankplot}}
}
\keyword{IO}
