\name{fspma.rankplot}
\alias{fspma.rankplot}
\alias{fspma.maplot}
\title{Data visualisation, FSPMA rank results and M/A Plots}
\description{
  These functions are useful tu visualise data that should be analysed
  by FSPMA. We provide rank plots and plots that visualise differential
  expression over spot amplitude.
}
\usage{
fspma.maplot(fspma.obj, slideno=1, pl.file='NA', pl.title='M-A Plot',
have.spike='no', nsmpls=50, xlab='Log Amplitude',
ylab='Log Ratio', cex=0.5, col=2, leg.pos='bottomright', leg.bty='n')
fspma.rankplot(fspma.obj, list.nam, no.genes=5, pl.title='Rank List',
pl.file='NA', plt.lwd=2, col.frst=T, leg.pos='bottomright', leg.bty='n',
def.xlabel='default', def.ylabel='default')
  }
\arguments{
  \item{fspma.obj}{is either a FSPMA object as generated by
    \code{\link{fspma.wrapper}}}
  \item{slideno}{number of slide that should be plotted in M/A representation}
  \item{pl.file}{a file name to store the figure as
    encapsulated postscript or 'new' if a new graphics window should be
    used. In the default case of 'NA', the current "device" is used for
    plotting.} 
  \item{pl.title}{Plot Title.}
  \item{have.spike}{Spike control: 'no' - spike genes are not plotted.
    'yes' spike genes are plotted if available.}
  \item{nsmpls}{Number of subsampled genes to be plotted.}
  \item{xlab}{X axis label.}
  \item{ylab}{Y axis label.}
  \item{cex}{Plot symbol size.}
  \item{col}{Point colour.}
  \item{leg.pos}{Position of legend (see plot legend function).}
  \item{leg.bty}{Type of legend bounding box (see plot legend function).}
  \item{list.nam}{Name of rank list to be visualised. The names replicate the names used in
    fspma.wrapper to write rank tables to files.}
  \item{no.genes}{Number of top ranked genes to be visualised.}
  \item{plt.lwd}{Point width of lines in the plot}
  \item{col.frst}{Boolean indicator whether to alter colors first and
    then symbols.}
  \item{def.xlabel}{String which overrides default X axis label.}
  \item{def.ylabel}{String which overrides default Y axis label.}  
}
\value{
  Neither function returns values. Both plot information.
}
\examples{
\dontrun{
fspma.obj <- fspma.wrapper('twochannel.def')
fspma.maplot(fspma.obj)
rank.tab.nams <- names(fspma.obj$plt.tab)
fspma.rankplot(fspma.obj, rank.tab.nams[1])
}
}
\seealso{
  \code{\link{fspma.wrapper}} and \code{\link{fspma.avchannel}}
}
\keyword{IO}
