\name{fspmaRG.2.RG}
\alias{fspmaRG.2.RG}
\alias{RG.2.fspmaRG}
\title{Conversion of FSPMA objects to and from RG}
\description{
  These functions act as adaptors from FSPMA objects to (YASMA's) RG
  object. They are meant to be used in cases where YASMA functions that
  operate on RG structures should collaborate with FSPMA.  
}
\usage{fspmaRG.2.RG(fspmaobj)
RG.2.fspmaRG(RG, fspmaobj)
}
\arguments{
  \item{fspmaobj}{is either a FSPMA object as generated by
    fspma.wrapper or a FSPMA RG object}
  \item{RG}{is a YASMA RG object (and possibly downwards compatible to SMA).}
}
\value{
\code{fspmaRG.2.RG} takes a FSPMA object and returns a YASMA RG object that can be passed on to
YASMA functions.
\code{RG.2.fspmaRG} takes s YASMA RG object and a FSPMA object and
returns a modified FSPMA object.
}
\examples{
\dontrun{
fspma.obj <- fspma.wrapper('twochannel.def')
yasma.rg <- fspmaRG.2.RG(fspma.obj)
## or alternatively with the same result
yasma.rg <- fspmaRG.2.RG(fspma.obj$RG)
## remove 0.1 quantile of least correlated genes
## or call other YASMA functions!
RG <- rg.remove.quantile(RG, 0.1)
## and merge the modified RG with the FSPMA object.
fspma.new <- RG.2.fspmaRG(RG, fspma.obj)
## to allow subsequent fspma analysis use externally
## modified data. e.g. here do the entire run on a reduced gene set.
fspma.res <- fspma.wrapper(RG=fspma.new$RG, info=fspma.new$info)
}
}
\seealso{
  \code{\link{tabdel2rg}} and \code{\link{fspma.wrapper}}
}
\keyword{IO}
