\name{read.defs}
\alias{read.defs}
\title{Read the fspma definition file and check consistency}
\description{Reads the definition file}
\usage{read.defs(fname, log.fname=fspma.logfile, init.logfile=T, print.logheader=T)}
\arguments{
  \item{fname}{File name of a definition file that controls the
    entire analysis.}
  \item{log.fname}{Name of log file which defaults to fspma.logfile or
    'fspma.log.txt', unless overriddenby the user.}
  \item{init.logfile}{Controls whether the logfile is initialised before
    starting the run. Its value defaults to TRUE.}
  \item{print.logheader}{Flag that controls whether the starting time is
    written to the log file.}
}
\value{Function \code{read.defs} returns the FSPMA info object. This is
  an R object that represents microarray data analysis as described in the
  definition file. Any manipulations at code level should be done with
  care and bearing in mind that the analysis result is no longer in
  agreement with the definition file.}
\details{
  The function reads the definition file, stores the information in the
  internally used info structure, which is checked for consistency.
  The consitency check is meant to avoid that apparent mistakes get
  caught before processing starts. In this context read.defs is useful
  as a stand alone function outside  \code{\link{fspma.wrapper}}, since
  it helps debugging the definition file. In that context it is worth
  mentioning that all problems with the definition file are reported
  on the R console and written into the log file. All messages
  point to those definition file entries that could have led to the
  problem. 
}
\examples{
\dontrun{
 info <- read.defs('mouse_testis_adult_day5.def')
 }
}
\seealso{
  \code{\link{fspma.wrapper}}, \code{\link{deffile.def}}
}
\keyword{IO}
