\name{spike.normalize}
\alias{spike.normalize}
\alias{get.spk.nrm.eqn}
\title{Normalization of array data with respect to spike probes
} 
\description{Functions for spike based normalisation.}
\usage{
get.spk.nrm.eqn(info, model.info)
spike.normalize(RG, info, model.info)
}
\arguments{
  \item{RG}{Modified (but compatible) yasma RG structure. Contains in
    addition to the usual entries the slide and grid number.
  }
  \item{info}{fspma's info structure, which has a new spike-gene list.}
  \item{model.info}{fspma's model.info structure, which has now a new
    model equation for spike normalization.}
}
\value{
  get.spk.nrm.eqn(info, model.info) generates model equations for spike
  based normalisation and augments model.info. The object
  model.info is not meant to be manipulated at user level.
  spike.normalize(RG, info, model.info) applies spike based
  normalisation to the aray data stored in RG, which it returns.
}
\details{
  The function spike.normalize normalises array data (in RG format)
  based on spike's that should be randomly positioned across the array.
  The normalisation procedure is controlled via the definition file entry
  Normalisation:, which in this case has to be "spike" with various
  options: "location" removes the within slide location; "spatial"
  removes a within slide loess fit conditional on spot position;
  "amplitude" removes a within slide loess fit conditional on amplitude.
  "spatial" and "amplitude" can be used together in which case the
  conditioning is on the space - amplitude interaction. Grid number can
  be included as interaction factor by specifying the modifier "grid".
  Finally one can remove scale as well by specifying "scale".
  The spike genes are defined together with amplitude factors,
  spike.name<TAB>R.spike<TAB>G.spike, where only the
  correct ratio is necessary. Spike based normalisation operates on
  the residual in log ratio, respectively "M" space (or on log
  expression residuals, if the input is one channel arrays).
  We get the following spike models that are used for a loess fit:
  \tabular{llllll}{
    spike \tab spatial \tab \tab \tab \tab  -->
    M-log(R.spike)+log(G.spike) ~ X:Y \cr
    spike \tab amplitude \tab \tab \tab \tab  -->
    M-log(R.spike)+log(G.spike) ~ A \cr
    spike \tab spatial \tab amplitude \tab grid \tab scale \tab -->
    M-log(R.spike)+log(G.spike) ~ X:Y:A:grid
  }
  in addition the last also divides by std. deviation over
  spike residuals, estimated for every
  sub grid separately.
}
\examples{
\dontrun{
## read definition file that specifies spike normalisation
info <- read.defs('mouse_testis_spike_norm.def')
## get relevant modelling information
model.info <- info.2.model.eqns(info)
## add spike model equation to model.info # (normally hidden in fspma.wrapper)
model.info <- get.spk.nrm.eqn(info, model.info)
## and call normalisation
RG <- spike.normalize(RG, info, model.info)
}
}
\seealso{
  \code{\link{fspma.wrapper}}, \code{\link{read.defs}},
  \code{\link{deffile.def}}, \code{\link{info.2.yasmaeqns}}, and \code{\link{treat.na}}
}
\keyword{manip}
\keyword{smooth}
