
sam.s0 <- function(r,s,s.step=0.01,alpha.step=0.01) {
  q <- quantile(s,seq(0,1,by=s.step))
  q.indices <- cut(s,q,labels=F,right=F)
  #q.ranges <- cut(s,q,labels=NULL,right=F)

  sam.d.alpha <- function(r,s,alpha) {
    s.alpha <- quantile(s,alpha)
    r/(s + s.alpha)
  }

  cv.alpha <- function(alpha) {
    d.alpha <- sam.d.alpha(r,s,alpha)

    v.j <- tapply(d.alpha,q.indices,mad)
    sd(v.j)/mean(v.j)
  }

  alpha.seq <- seq(0,1,by=alpha.step)
  cva <- sapply(alpha.seq,cv.alpha)
  plot(cva,ty="l")
  alpha0 <- alpha.seq[which(cva == min(cva))]
  quantile(s,alpha0)
}

sam.single.rg <- function(RG,...) {
  f <- rg.log.matrix(RG)
  sam.single(f,...)
}

sam.single <- function(f,rounds=200,do.row.perms=F,quantile.s0=NULL,
    fast=T,sampling=c("systematic","resampling"),
    centralize=T) {
  sampling <- match.arg(sampling)
  if (centralize)
    f <- scale(f,scale=F)
  m <- ncol(f)
  n <- nrow(f)

  sqrt.m <- sqrt(m)
  r <- apply(f,1,mean)
  s <- apply(f,1,sd)/sqrt.m

  if (is.null(quantile.s0)) {
    s0 <- sam.s0(r,s)
  } else {
    s0 <- quantile(s,quantile.s0)
  }

  d <- r/(s + s0)
  o <- order(d)
  tf <- t(f)

  dlist <- list()
  if (sampling == "resampling") {
    # bootstrap resampling, doesn't work as well
    for (i in 1:m)
      dlist <- c(dlist,list(0:m))
    perms.all <- as.matrix(do.call("expand.grid",dlist))
    perms <- perms.all[which(apply(perms.all,1,sum)==4),]
  } else if (sampling == "systematic" && 2^m > rounds) {
    perms <- NULL
    for (i in 1:rounds)
      perms <- rbind(perms,sample(c(-1,1),m,repl=T))
  } else if (sampling == "systematic") {
    for (i in 1:m)
      dlist <- c(dlist,list(c(-1,1)))
    perms <- as.matrix(do.call("expand.grid",dlist))
    # maybe remove first -1,-1,-1 and last 1,1,1 ?
    # which yields original -d and d
    #perms <- perms[-c(1,nrow(perms)),]
  } else
    stop("unknown sampling method")

  if (!do.row.perms)
    rounds <- nrow(perms)

  if (fast) {
    ind <- rep(0,m)
    d.all <- matrix(0,n,rounds)
    d.all <- matrix(.C("sam_single",
      as.integer(rounds),
      as.integer(t(perms)),
      as.integer(nrow(perms)),
      as.integer(do.row.perms),
      as.integer(n),
      as.integer(m),
      as.double(s0),
      as.double(t(f)),
      d.all=as.double(d.all)
    )$d.all,n,rounds)
  } else {
    d.all <- NULL
    for (i in 1:rounds) {
      cat(i," ")
      signs <- perms[i,]
      f.b <- tf * signs
      r.b <- apply(f.b,2,mean)
      s.b <- apply(f.b,2,sd)/sqrt.m
      d.b <- r.b/(s.b + s0)
      o.b <- order(d.b)
      d.b.o <- d.b[o.b]
      d.all <- cbind(d.all,d.b.o)
    }
    cat("\n")
  }

  list(d=d,o=o,d.all=d.all,s0=s0)
}

sam.two.class.rg <- function(RG,...) {
  f <- rg.log.matrix(RG)
  sam.two.class(f,...)
}

sam.two.class <- function(f,m1=0,rounds=NULL,
    quantile.s0=NULL,centralize=T,fast=T) {
  if (centralize)
    f <- scale(f,scale=F)
  m <- ncol(f)
  n <- nrow(f)
  if (m1 == 0) {
    m1 <- m/2
  }
  m2 <- m - m1

  inds1 <- 1:m1
  inds2 <- (m1+1):m
  s.factor <- sqrt((1/m1 + 1/m2)/(m1 + m2 - 2))

  #r <- apply(f[,inds1],1,mean) - apply(f[,inds2],1,mean)
  #s <- apply(f[,inds1],1,var)*(m1-1) +
  #    apply(f[,inds2],1,var)*(m2-1)}
  r1 <- apply(f[,inds1],1,mean)
  r2 <- apply(f[,inds2],1,mean)
  r <- r1 - r2
  s <- (apply(f[,inds1]^2,1,sum) - r1^2*m1) +
      (apply(f[,inds2]^2,1,sum) - r2^2*m2)
  s <- sqrt(s) * s.factor

  if (is.null(quantile.s0)) {
    s0 <- sam.s0(r,s)
  } else {
    s0 <- quantile(s,quantile.s0)
  }

  d <- r/(s + s0)
  o <- order(d)
  tf <- t(f)

  perms <- NULL
  sub.sets <- fixed.s.subsets(m1+m2,m1)
  for (i in seq(along=sub.sets)) {
    perms <- rbind(perms,c(sub.sets[[i]],(1:m)[-sub.sets[[i]]]))
  }

  if (is.null(rounds)) {
    rounds <- nrow(perms)
    do.row.perms <- F
  } else {
    do.row.perms <- T
  }

  if (fast) {
    cat("fast\n")
    d.all <- matrix(0,n,rounds)
    #d.all <- matrix(0,2,rounds)
    cperms <- perms - 1 # VERY, VERY IMPORTANT
    d.all <- matrix(.C("sam_two_class",
      as.integer(rounds),
      as.integer(t(cperms)),
      as.integer(nrow(cperms)),
      as.integer(do.row.perms),
      as.integer(n),
      #as.integer(2),
      as.integer(m1),
      as.integer(m2),
      as.double(s0),
      as.double(t(f)),
      #as.double(t(f[1:2,])),
      d.all=as.double(d.all)
    )$d.all,n,rounds)
    #)$d.all,2,rounds)
  } else {
    cat("slow\n")
    d.all <- NULL
    for (i in 1:rounds) {
      cat(i," ")
      pinds1 <- perms[i,inds1]
      pinds2 <- perms[i,inds2]
      #r.b <- apply(f[,pinds1],1,mean) - apply(f[,pinds2],1,mean)
      #s.b <- apply(f[,pinds1],1,var)*(m1-1) +
      #    apply(f[,pinds2],1,var)*(m2-1)
      r1 <- apply(f[,pinds1],1,mean)
      r2 <- apply(f[,pinds2],1,mean)
      r.b <- r1 - r2
      s.b <- (apply(f[,pinds1]^2,1,sum) - r1^2*m1) +
          (apply(f[,pinds2]^2,1,sum) - r2^2*m2)
      s.b <- sqrt(s.b) * s.factor

      d.b <- r.b/(s.b + s0)
      o.b <- order(d.b)
      d.b.o <- d.b[o.b]
      d.all <- cbind(d.all,d.b.o)
    }
    cat("\n")
  }

  list(d=d,o=o,d.all=d.all,s0=s0)
}

sam.fdr <- function(sam,over=T,score=T,exclude=F) {
  v <- sam$d
  v.all <- sam$d.all
  v.av <- apply(v.all,1,mean)
  o.d <- order(sam$d)
  v.o <- v[o.d]
  if (!score) {
    if (exclude) {
      # exclude bootstrap sample itself from it's average
      # calculation, see MAs&UCE p 15
      d.all.av <- NULL
      for (i in 1:ncol(sam$d.all))
        d.all.av <- cbind(d.all.av,apply(sam$d.all[,-i],1,mean))
      v.all <- d.all - d.all.av
    }
    v.all <- v.all - v.av %o% rep(1,ncol(v.all))
    v <- v.o - v.av
    o.v <- order(v)
    v <- v[o.v]  # is done in cut automatically
  }
  #for debug:
  #tc <- table(cut(v.all,
  #    c(v[(length(v)-10):length(v)],10000,-10000),right=F))
  if (over) {
    tc <- table(cut(v.all,c(v,10000,-10000),right=F))
    cs <- cumsum(tc[length(tc):1]) # cumsum from right
  } else {
    tc <- table(cut(v.all,c(v,10000,-10000),right=T))
    cs <- cumsum(tc)               # cumsum from left
  }
  fdr <- cs/ncol(v.all)/(1:length(tc))
  if (over)
    fdr <- fdr[length(fdr):1] # revert cumsum from right
  fdr <- fdr[-1]     # remove [-infty,min(v)) interval
  if (!score) {
    fdr[o.v] <- fdr # rev effect of v ordering
  }
  fdr[o.d] <- fdr    # rev effect of o.d
  fdr[fdr > 1] <- 1
  fdr                # now it fits to sam$d again
}

sam.stats <- function(genes,sam,delta.seq,over=T,do.plot=T) {
  d.av <- apply(sam$d.all,1,mean)
  d.o <- sam$d[sam$o]
  #if (!over) {
  #  d.o <- -d.o[length(d.o):1]
  #  d.av <- -d.av[length(d.av):1]
  #  o <- o[length(o):1]
  #}

  d.diff <- d.o - d.av

  called <- list()
  inds.lst <- list()
  stats <- NULL
  for (delta in delta.seq) {
    if (do.plot) {
      plot(d.av,d.o)
      lines(c(-10,10),c(-10,10))
      lines(c(-10,10),c(-10-delta,10-delta),lty="dashed",col="red")
      lines(c(-10,10),c(-10+delta,10+delta),lty="dashed",col="red")
    }
    if (over)
      inds.o <- which(d.diff > delta)
    else
      inds.o <- which(d.diff < -delta)
    if (length(inds.o) > 0) {
      if (over) {
        cut <- min(d.o[inds.o])
        ftotal <- sum(sam$d.all >= cut)
      } else {
        cut <- max(d.o[inds.o])
        ftotal <- sum(sam$d.all <= cut)
      }
      fdr <- ftotal / ncol(sam$d.all) / length(inds.o)
      inds <- sam$o[inds.o]
      inds.lst <- c(inds.lst,list(inds))
      called <- c(called,list(genes[inds]))
      stats <- rbind(stats,c(delta,fdr,cut,length(inds.o)))
    }
  }

  colnames(stats) <- c("delta","fdr","cut","called")
  list(stats=stats,called=called,inds=inds.lst,over=over)
}

shift.quantile <- function(x,s) {
  q <- quantile(x,s)
  get.left <- function(p) {
    (max(x[x < p]) + p) / 2
  }
  sapply(q[2:(length(q)-1)],get.left)
}

normal.transform <- function(basis,use.ns=F,reverse=F,do.plot=T) {
  require(splines)
  q <- qqnorm(basis,plot.it=do.plot)
  o <- order(q$x)
  if (!reverse) {
    nq <- q$x[o]
    bq <- q$y[o]
  } else {
    bq <- q$x[o]
    nq <- q$y[o]
  }  
  plot(bq,nq)
  if (use.ns) {
    knots <- shift.quantile(bq,seq(0,1,0.1))
    #knots <- (knots[2:length(knots)]+knots[1:(length(knots)-1)]) / 2
    #knots <- c(min(bq)-0.1,knots,max(bq)+0.1)
    b.knots <- range(c(bq,knots))
    b.ft <- lm(nq ~ ns(bq,knots=knots,Boundary=b.knots))
    pred <- function(vec) {
      # bq important in data.frame!!!
      as.vector(predict(b.ft,data.frame(bq=vec)))
    }
    lines(bq,pred(bq),col="green")
    points(c(-2,0,2),pred(c(-2,0,2)),col="red")
  } else {
    #b.ft <- loess(nq ~ bq,span=0.2,
    #    control=loess.control(surface="direct"))
    b.ft <- smooth.spline(bq,nq,df=15)
    #lines(bq,fitted(b.ft))
    #lines(bq,predict(b.ft,data.frame(bq)))
    pred <- function(vec) {
      #ind.ok <- which(!is.na(vec))
      #pvec <- vec
      #pvec[ind.ok] <- predict(b.ft,vec[ind.ok])$y
      predict(b.ft,vec)$y
      #if (any(is.na(vec)))
      #  pvec[which(is.na(vec))] <- NA
    }
    lines(bq,pred(bq))
  }
  list(t.lm=b.ft,pred=pred,basis=basis)
}

get.normal.transform <- function(nt,data) {
  apply(as.matrix(data),2,nt$pred)
}

prob.success <- function(d.n,d.all.n,df=4,
    low=NULL,high=NULL,length=50) {
  #cuts <- seq(-4,4,len=81)
  rg <- range(c(d.n,d.all.n))
  if (is.null(low))
    low <- rg[1]
  if (is.null(high))
    high <- rg[2]
  cuts <- seq(low-0.01,high+0.01,length=length)
  d.c <- table(cut(d.n,cuts))
  d.all.c <- table(cut(d.all.n,cuts))
  x <- (cuts[2:length(cuts)] + cuts[1:(length(cuts)-1)]) / 2
  #knots <- cuts[seq(1+20,61-20,20)]
  #b.knots <- c(-4,4)
  knots <- shift.quantile(x,seq(0,1,len=df))
  b.knots <- range(c(x,knots))
  p.m <- as.matrix(cbind(d.c,d.all.c))
  f0.glm <- glm(p.m ~ ns(x,knots=knots,Boundary=b.knots),binomial)
  pred <- function(vec) {
    # x important in data.frame!!!
    if (length(vec) >= 2)
      as.vector(predict(f0.glm,data.frame(x=vec),type="response"))
    else
      as.vector(predict(f0.glm,data.frame(x=c(vec,0)),type="response"))[1]
  }
  #plot(x,fitted(f0.glm))
  z <- seq(low,high,0.1)
  plot(z,pred(z),ty="l")
  #points(c(-2,0,2),pred(c(-2,0,2)),col="red")
  z <- seq(low,high,0.05)
  ps <- list(f0.glm=f0.glm,x=x,pred=pred,B=ncol(d.all.n),p.m=p.m)
  p0 <- min(1/f0.over.f(z,ps))
  ps$p0 <- p0
  ps
}

f0.over.f <- function(x,ps) {
  p <- ps$pred(x)
  p[which(is.na(x))] <- NA
  (1-p)/(ps$B*p) 
}

plot.f0.over.f <- function(ps,low,high,p0=NULL,method=plot,...) {
  if (is.null(p0)) p0 <- ps$p0
  z <- seq(low,high,0.1)
  method(z,f0.over.f(z,ps),ty="l",...)
}

p1 <- function(x,ps,p0=NULL) {
  if (is.null(p0)) p0 <- ps$p0
  f0f <- f0.over.f(x,ps)
  1-p0*f0f
}

plot.p1 <- function(ps,low,high,nt.rev=NULL,p0=NULL,do.plot=T,...) {
  if (is.null(p0)) p0 <- ps$p0
  z <- seq(low,high,0.03)
  if (!is.null(nt.rev)) {
    z <-  get.normal.transform(nt.rev,z)
    low <- get.normal.transform(nt.rev,low)
    high <- get.normal.transform(nt.rev,high)
  }
  if (do.plot) {
    plot(z,p1(z,ps=ps,p0=p0),ty="l",xlab="Z",
        ylab="P[diff expr|Z]",...)
    lines(c(-20,20),c(0,0),lty=1)
    lines(c(-20,20),c(1,1),lty=1)
  } else {
    lines(z,p1(z,ps=ps,p0=p0),...)
  }
}

plot.f1.f0 <- function(ps,low,high,p0,odds=F,nt.rev=NULL) {
  z <- seq(low,high,0.03)
  f <- dnorm(z)
  f0 <- f0.over.f(z,ps)*f
  p1.f1 <- f - p0*f0
  if (!is.null(nt.rev)) {
    z <- get.normal.transform(nt.rev,z)
  }
  if (odds) {
    opar <- par(mfrow=c(2,1))
    on.exit(opar)
    plot(z,log(p1.f1/(p0*f0),2),ylim=c(-10,10),ty="l")
  }
  plot(z,f,ty="l",lwd=2,lty=2,xlab="Z",ylab="")

  lines(z,p0*f0,lty=3,lwd=2)
  lines(z,p1.f1,lty=1,lwd=2)
  lines(c(-50,50),c(0,0))
  legend(2,0.7*max(p0*f0),c("f1","f0","f"),lty=c(1,3,2),bty="n")
}

f.func <- function(ps) {
  function(x) dnorm(x)
}

f1.func <- function(ps) {
  function(x) dnorm(x)*(1 - ps$p0*f0.over.f(x,ps))/(1-ps$p0)
}

f0.func <- function(ps) {
  function(x) f0.over.f(x,ps)*dnorm(x)
}

sam.table.ou <- function(al,genes,sam,
    prob.l=NULL,prob.h=NULL,split.size=0) {
  #al <- rg.log.matrix(RG)
  al <- scale(al,scale=F)
  if (split.size > 0) {
    al.av <- apply(al[,1:split.size],1,mean)
        - apply(al[,split.size:ncol(al)],1,mean)
  } else {
    al.av <- apply(al,1,mean)
  }
  fold <- 2^al.av
  d <- sam$d
  o <- order(d,fold)
  s.fdr.o <- sam.fdr(sam,over=T,score=T)
  s.fdr.u <- sam.fdr(sam,over=F,score=T)
  d.fdr.o <- sam.fdr(sam,over=T,score=F)
  d.fdr.u <- sam.fdr(sam,over=F,score=F)
  
  len <- length(d)
  if (is.null(prob.l)) {
    over.dfr <- data.frame(
        nb=1:len,
        gene=genes[o][len:1],
        score=d[o][len:1],
        #d.fdr=d.fdr.o[o][len:1],
        fdr=s.fdr.o[o][len:1],
        fold=(fold[o])[len:1] )
    under.dfr <- data.frame(
        nb=1:len,
        gene=genes[o],
        score=d[o],
        #d.fdr=d.fdr.u[o],
        fdr=s.fdr.u[o],
        fold=fold[o] )
  } else {
    over.dfr <- data.frame(
        nb=1:len,
        gene=genes[o][len:1],
        score=d[o][len:1],
        #d.fdr=d.fdr.o[o][len:1],
        fdr=s.fdr.o[o][len:1],
        prob.l=prob.l[o][len:1],
        prob.h=prob.h[o][len:1],
        fold=(fold[o])[len:1] )
    under.dfr <- data.frame(
        nb=1:len,
        gene=genes[o],
        score=d[o],
        #d.fdr=d.fdr.u[o],
        fdr=s.fdr.u[o],
        prob.l=prob.l[o],
        prob.h=prob.h[o],
        fold=fold[o] )
  }
  list(over.dfr=over.dfr,under.dfr=under.dfr)
}

sam.write.ou <- function(ou,limit.o=NULL,
    limit.u=NULL,prefix="") {
  len <- nrow(ou$over.dfr)
  if (is.null(limit.o)) limit.o <- len
  if (is.null(limit.u)) limit.u <- len
  write.table(ou$over.dfr[1:limit.o,],
      file=paste(prefix,"sam_over.dat",sep=""),
      sep="\t",quote=F,row.names=F )
  write.table(ou$under.dfr[1:limit.u,],
      file=paste(prefix,"sam_under.dat",sep=""),
      sep="\t",quote=F,row.names=F )
}

sam.analyse.rg <- function(RG,...) {
  f <- rg.log.matrix(RG)
  sam.analyse(f,genes=RG$genes,...)
}

sam.analyse <- function(f,genes,prefix="",low=-3,high=3,
    single=T,split.size=0,rounds=200,quantile.s0=NULL,do.row.perms=F) {
  if (!single && split.size == 0)
    split.size <- ncol(f)/2
  dyn.load("/home/wernisch/microarrays/progs/sam.so");
  if (single) {
    cat("single\n")
    sam <- sam.single(f,quantile.s0=quantile.s0,rounds=rounds,
        fast=T,do.row.perms=do.row.perms)
  } else {
    cat("two class, split size ",split.size,"\n")
    sam <- sam.two.class(f,m1=split.size,
        quantile.s0=quantile.s0,rounds=rounds,fast=T)
  }
  #sa.o <- sam.stats(genes,sam,seq(0.2,3,0.1),over=T,do.plot=T)
  #print(sa.o$stats)
  #sa.u <- sam.stats(genes,sam,seq(0.2,3,0.1),over=F,do.plot=T)
  #print(sa.u$stats)
  d <- sam$d
  d.all <- sam$d.all
  nt <- normal.transform(d,use.ns=F,do.plot=T)
  nt.rev <- normal.transform(d,use.ns=F,rev=T,do.plot=T)
  d.n <- get.normal.transform(nt,d)
  d.all.n <- get.normal.transform(nt,d.all)
  ps <- prob.success(d.n,d.all.n,low=low,high=high)
  z <- seq(low,high,0.05)
  p0 <- ps$p0

  postscript(file=paste(prefix,"bayesian.ps",sep=""),
     paper="special",horizontal=F,width=6,height=6)
  plot.p1(ps,low,high,nt.rev=nt.rev,do.plot=T,lwd=2) # xlim=c(low,high))
  plot.p1(ps,low,high,do.plot=F,nt.rev=nt.rev,p0=1,lty="dashed",lwd=2)
  dev.off()

  postscript(file=paste(prefix,"null.ps",sep=""),
     paper="special",horizontal=F,width=6,height=6)
  plot.f1.f0(ps,low,high,p0,nt.rev=nt.rev)
  dev.off()

  #cut.o <- get.normal.transform(nt,sa.o$stats[,"cut"])
  #stats.o <- cbind(sa.o$stats,prob=p1(cut.o,ps))
  #cut.u <- get.normal.transform(nt,sa.u$stats[,"cut"])
  #stats.u <- cbind(sa.u$stats,prob=p1(cut.u,ps))
  sam.ou <- sam.table.ou(f,genes,sam,p1(d.n,ps,1),p1(d.n,ps,p0),
      split.size=split.size)
  sam.write.ou(sam.ou,prefix=prefix)  
  sam
}
